@@ -30,7 +30,7 @@ use LWP::UserAgent;
 use Web::Scraper;
 use String::Util qw(trim);
 
-our $VERSION = '1.62_01'; # TRIAL VERSION
+our $VERSION = '1.62_02'; # TRIAL VERSION
 
 our $DISPLAY    = 'NZX - New Zealand Exchange';
 our @LABELS     = qw/last isin name currency date isodate/;
@@ -89,6 +89,7 @@ sub nzx {
         
         $info{$symbol, 'success'}  = 1;
         $info{$symbol, 'currency'} = 'NZD';
+        $info{$symbol, 'symbol'}  = $symbol;
         $info{$symbol, 'last'}    = $json_data->{'props'}{'pageProps'}{'overview'}{'priceAmount'};
         $info{$symbol, 'isin'}    = $json_data->{'props'}{'pageProps'}{'overview'}{'ISIN'};
         $info{$symbol, 'name'}    = $json_data->{'props'}{'pageProps'}{'overview'}{'name'};
@@ -111,6 +112,8 @@ sub nzx {
 
 1;
 
+__END__
+
 =head1 NAME
 
 Finance::Quote::NZX - Obtain quotes from New Zealand's
@@ -122,11 +125,11 @@ Exchange www.nzx.com
 
     $q = Finance::Quote->new;
 
-    %stockinfo = $q->fetch('nzx','TPW');
+    %stockinfo = $q->fetch('nzx','MNW');
 
 =head1 DESCRIPTION
 
-This module obtains information fromwww.nzx.com.
+This module obtains information from L<NZX|https://www.nzx.com/>.
 
 =head1 LABELS RETURNED
 
